def print_lol(the_list, level):
    for each_item in the_list:
        if isinstance(each_item, list):
            print_lol(each_item, level+1)
        else:
            for tab_stop in range(level):
            	print("\t", end="")
            print(each_item)


from distutils.core import setup

setup(
		name = 'ml_nester',
		version = '1.1.0',
		py_modules = ['nester'],
		author = 'MagnusLislevatn',
		author_email = 'magnus.lislevatn@gmail.com',
		url = 'http://magnuslisleva.tn',
		description = 'A simple printer of nested lists',
	)
